==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/ka.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "მართვა Lightbox Gallary პარამეტრები");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "მართვა გალერეა");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image სიგანე");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image სიმაღლე");
define('MANAGE_GALLERY_THUMB_WIDTH', "მინიატურა სურათის სიგანე");
define('MANAGE_GALLERY_THUMB_HEIGHT', "მინიატურა სურათის სიმაღლე");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "შეინარჩუნოს Thumb თანაფარდობა");
define('MANAGE_GALLERY_SHOW_TITLES', "Show წოდებების");
define('MANAGE_GALLERY_DISABLE_SORT', "შეზღუდული შესაძლებლობების მქონე დალაგება");
define('MANAGE_GALLERY_DELETE_IMAGE', "სურათის წაშლა");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "გადავარჩინოთ სორტირების");
define('MANAGE_GALLERY_PUBLISH_MSG', "დაწკაპეთ &quot;განახლება&quot; გამოაქვეყნოს <br /> თქვენი ატვირთული images.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "ყველა სურათები არ შეცვლის და პარამეტრები შენახულია.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "შეცდომა იყო resizing გამოსახულება ან გადარჩენის პარამეტრები.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "შენი სურათი (s) აიტვირთა.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "მოხდა შეცდომა, თქვენი სურათის ატვირთვა (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "ფაილი თქვენ ცდილობთ ატვირთოთ არ არის გამოსახულება.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "ფაილი თქვენ ცდილობთ ატვირთოთ არის ძალიან დიდი.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "სათაური შენახულია.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "დარწმუნებული ხართ, რომ გსურთ წაშალოთ სურათი");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "სურათი წაიშალა.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "შეცდომა იყო წაშლის იმიჯი.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "შენახვა პარამეტრების და resizing, სურათებით, გთხოვთ დაელოდოთ ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "ატვირთვა, გთხოვთ დაელოდოთ ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "სორტირების არ შენახულა. გსურთ გადარჩენა სორტირების?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "იმიჯი სორტირების შენახულია.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "შეცდომა იყო გადარჩენის იმიჯი დალაგება.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ka.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "მართვა Lightbox Gallary პარამეტრები");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "მართვა გალერეა");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image სიგანე");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image სიმაღლე");
define('MANAGE_GALLERY_THUMB_WIDTH', "მინიატურა სურათის სიგანე");
define('MANAGE_GALLERY_THUMB_HEIGHT', "მინიატურა სურათის სიმაღლე");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "შეინარჩუნოს Thumb თანაფარდობა");
define('MANAGE_GALLERY_SHOW_TITLES', "Show წოდებების");
define('MANAGE_GALLERY_DISABLE_SORT', "შეზღუდული შესაძლებლობების მქონე დალაგება");
define('MANAGE_GALLERY_DELETE_IMAGE', "სურათის წაშლა");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "გადავარჩინოთ სორტირების");
define('MANAGE_GALLERY_PUBLISH_MSG', "დაწკაპეთ &quot;განახლება&quot; გამოაქვეყნოს <br /> თქვენი ატვირთული images.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "ყველა სურათები არ შეცვლის და პარამეტრები შენახულია.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "შეცდომა იყო resizing გამოსახულება ან გადარჩენის პარამეტრები.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "შენი სურათი (s) აიტვირთა.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "მოხდა შეცდომა, თქვენი სურათის ატვირთვა (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "ფაილი თქვენ ცდილობთ ატვირთოთ არ არის გამოსახულება.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "ფაილი თქვენ ცდილობთ ატვირთოთ არის ძალიან დიდი.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "სათაური შენახულია.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "დარწმუნებული ხართ, რომ გსურთ წაშალოთ სურათი");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "სურათი წაიშალა.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "შეცდომა იყო წაშლის იმიჯი.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "შენახვა პარამეტრების და resizing, სურათებით, გთხოვთ დაელოდოთ ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "ატვირთვა, გთხოვთ დაელოდოთ ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "სორტირების არ შენახულა. გსურთ გადარჩენა სორტირების?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "იმიჯი სორტირების შენახულია.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "შეცდომა იყო გადარჩენის იმიჯი დალაგება.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "ფაილი, რომლის ატვირთვასაც ცდილობენ, უფრო დიდია, ვიდრე &#39;upload_max_filesize&#39; ან &#39;post_max_size&#39; PHP პარამეტრები. დაუკავშირდით თქვენს სისტემის ადმინისტრატორს ამ შეზღუდვების გაზრდისთვის.");
?>
